<?php
/**
 * Static content controller.
 *
 * This file will render views from views/pages/
 *
 * PHP 5
 *
 * CakePHP(tm) : Rapid Development Framework (http://cakephp.org)
 * Copyright 2005-2012, Cake Software Foundation, Inc. (http://cakefoundation.org)
 *
 * Licensed under The MIT License
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright 2005-2012, Cake Software Foundation, Inc. (http://cakefoundation.org)
 * @link          http://cakephp.org CakePHP(tm) Project
 * @package       app.Controller
 * @since         CakePHP(tm) v 0.2.9
 * @license       MIT License (http://www.opensource.org/licenses/mit-license.php)
 */

App::uses('AppController', 'Controller');
App::uses('ArrayUtil', 'EvCore.Lib');
App::uses('Folder', 'Utility');

/**
 * Static content controller
 *
 * Override this controller by placing a copy in controllers directory of an application
 *
 * @package       app.Controller
 * @link http://book.cakephp.org/2.0/en/controllers/pages-controller.html
 */
class PagesController extends AppController {

/**
 * Controller name
 *
 * @var string
 */
	public $name = 'Pages';


	public function beforeFilter() {

		parent::beforeFilter();

		$this->Auth->allow(array(
			'home',
			'view'
		));

	}


	protected function _adminIndexColumns() {

		$columns = parent::_adminIndexColumns();

		$columns = ArrayUtil::addAfter(
			$columns,
			'Page.title',
			array(
				'Route.alias' => array(
					'label' => 'URL',
					'type' => 'string'
				)
			)
		);

		return $columns;
	}


	protected function _adminFormFields() {

		$Model = $this->{$this->modelClass};

		$fields = parent::_adminFormFields();

		// remove the view_template field if we are no evoluted admin
		if (intval($this->Auth->user('User.user_group_id')) === 1) {

			$fields[$Model->alias . '.view_template']['type'] = 'select';
		} else {

			unset($fields[$Model->alias . '.view_template']);
		}

		return $fields;
	}


	protected function _adminPopulateLookups() {

		// search for all the view templates in the pages folder to save having to enter manually
		// can provide a nice dropdown instead
		$viewTemplates = array();

		$dir = new Folder(APP . 'View' . DS . 'Pages');
		$files = $dir->find('.*\.ctp');

		foreach ($files as $file) {

			if ($file === 'view.ctp') {

				continue;
			}

			$filename = substr($file, 0, -4);
			$viewTemplates[$filename] = $filename;
		}

		$this->set('viewTemplates', $viewTemplates);
	}


	public function view($id) {

		$Model = $this->{$this->modelClass};
		$data = $Model->readForView($id);

		if (!$data) {
			throw new NotFoundException();
		}

		$this->set('data', $data);
		$this->Meta->set($data);
		$this->view = 'view';

		// Check if we're overriding the view template.
		if (!empty($data['Page']['view_template'])) {

			$this->view = $data['Page']['view_template'];

			// Check if we need to grab any extra data for this template.
			$template = Inflector::camelize($data['Page']['view_template']);
			if (method_exists($this, '_get' . $template . 'Extras')) {
				$method = '_get' . $template . 'Extras';
				$this->$method();
			}
		}

		return;

	}


	/**
	 * Displays a view
	 *
	 * @param mixed What page to display
	 * @return void
	 */
	public function display() {
		$path = func_get_args();

		$count = count($path);
		if (!$count) {
			$this->redirect('/');
		}
		$page = $subpage = $title_for_layout = null;

		if (!empty($path[0])) {
			$page = $path[0];
		}
		if (!empty($path[1])) {
			$subpage = $path[1];
		}
		if (!empty($path[$count - 1])) {
			$title_for_layout = Inflector::humanize($path[$count - 1]);
		}
		$this->set(compact('page', 'subpage', 'title_for_layout'));
		$this->render(implode('/', $path));
	}

}
